summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Teigland <teigland@redhat.com>2009-05-28 14:43:44 -0500
committerDavid Teigland <teigland@redhat.com>2009-05-28 14:43:44 -0500
commite35d034dc3c573576184909c8ceff614be1e77d4 (patch)
treef7ee4902c5648c8889b2b2f8605cfd19b74a8d44
parent2de0c639c305773afdbba412a0ca49f47e1dd149 (diff)
downloaddct-stuff-e35d034dc3c573576184909c8ceff614be1e77d4.tar.gz
dct-stuff-e35d034dc3c573576184909c8ceff614be1e77d4.tar.xz
dct-stuff-e35d034dc3c573576184909c8ceff614be1e77d4.zip
cpgx: more frequent sending
Signed-off-by: David Teigland <teigland@redhat.com>
-rw-r--r--cpgx/cpgx.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/cpgx/cpgx.c b/cpgx/cpgx.c
index b6e5934..639b8ed 100644
--- a/cpgx/cpgx.c
+++ b/cpgx/cpgx.c
@@ -1184,8 +1184,7 @@ static void receive_time(struct dct_header *hd, int len)
}
node->last_check_eventid = end_eventid;
- /* this check currently fails with corosync,
- TODO: add option to enable this check */
+ /* this check currently fails with corosync */
#if 0
/* Track whether messages sent in configuration C1 are delivered in C1
instead of a subsequent C2. Recent reading led me to believe that
@@ -1359,7 +1358,7 @@ int do_leave(void)
static struct timeval last_send;
static int wait_send;
/* random interval from 5 to 100 ms between every send */
int we_should_send(void)
{
@@ -1372,7 +1371,7 @@ int we_should_send(void)
if (ms >= wait_send) {
last_send = now;
- wait_send = rand_int(5, 100);
+ wait_send = rand_int(5, 50);
return 1;
}
return 0;
@@ -1359,7 +1358,7 @@ int do_leave(void)
static struct timeval last_send;
static int wait_send;
-/* random interval from 5 to 100 ms between every send */
+/* random interval from 5 to 50 ms between every send */
int we_should_send(void)
{